@@ -421,7 +421,7 @@ CPS* DCP::cps(CTRL& ctrl){
 	  Fval(j) = feval(x(span(0, ne - 1), span::all), nF[j]);
 	}
 	Fval[0] -= x.at(n - 1, 0); 
-	if(is_finite(Fval)){
+	if(Fval.is_finite()){
 	  backTrack = false;
 	} else {
 	  step *= beta;
