@@ -328,7 +328,7 @@ CPS* DNL::cps(CTRL& ctrl){
 	for(int j = 0; j < mnl; j++){
 	  Fval(j) = feval(x, nF[j]);
 	}
-	if(is_finite(Fval)){
+	if(Fval.is_finite()){
 	  backTrack = false;
 	} else {
 	  step *= beta;
