@@ -292,7 +292,7 @@ CPS* gpp(std::vector<mat> FList, std::vector<mat> gList, CONEC& cList, mat A, ma
 	  Fval.at(j, 0) = ymax + log(ysum);
 	}
 	Fval.at(0, 0) -= x.at(n - 1, 0); 
-	if(is_finite(Fval)){
+	if(Fval.is_finite()){
 	  backTrack = false;
 	} else {
 	  step *= beta;
