@@ -234,7 +234,7 @@ CPS* rpp(mat x0, mat P, mat mrc, CTRL& ctrl){
       while(backTrack){
 	x = pdv->x + step * dpdv->x;
 	Fval = rpp_f0(x(span(0, ne - 1), span::all), P, mrc) - x.at(n - 1, 0);
-	if(is_finite(Fval)){
+	if(std::isfinite(Fval)){
 	  backTrack = false;
 	} else {
 	  step *= beta;
